// Copyright (c) 2015, XMOS Ltd, All rights reserved
#include "u_series_adc.h"
#include "debug_print.h"

#define PRINT_PERIOD    10000000
#define TRIGGER_PERIOD    100000

on tile[0] : port trigger_port = PORT_ADC_TRIGGER;
on tile[0] : clock cl = XS1_CLKBLK_2;

void adc_example(chanend c)
{
    timer        print_timer;
    unsigned int print_time;

    // A value that is not possible to get from the 12-bit ADC
    unsigned int current_value = 0xfff;
    unsigned int new_value = 0;

    adc_config_t adc_config = { { 0, 0, 0, 0, 0, 0, 0, 0 }, 0, 0, 0 };

    adc_config.input_enable[0] = 1;
    adc_config.bits_per_sample = ADC_32_BPS;
    adc_config.samples_per_packet = 1;
    adc_config.calibration_mode = 0;

    adc_enable(usb_tile, c, trigger_port, adc_config);

    print_timer :> print_time;
    print_time += PRINT_PERIOD;

    adc_trigger_packet(trigger_port, adc_config);

    while (1)
    {
        unsigned data[1];

        select
        {
            case print_timer when timerafter(print_time) :> void:
                if (new_value != current_value)
                {
                    debug_printf("ADC value: 0x%x\n", new_value);
                    current_value = new_value;
                }
                print_time += PRINT_PERIOD;
                break;

            case adc_read_packet(c, adc_config, data):
                new_value = data[0];
                adc_trigger_packet(trigger_port, adc_config);
                break;
        }
    }
}

int main()
{
    chan c;

    par {
        on tile[0]: adc_example(c);
        xs1_su_adc_service(c);
    }

    return 0;
}

